/*=========================================================================
| KCalDAV
|--------------------------------------------------------------------------
| (c) 2009  Kumaran Santhanam
|
| This project is released under the GNU General Public License.
| Please see the file COPYING for more details.
|--------------------------------------------------------------------------
| Configuration and properties dialog
 ========================================================================*/

#ifndef KCAL_RESOURCECALDAVCONFIG_H
#define KCAL_RESOURCECALDAVCONFIG_H

/*=========================================================================
| INCLUDES
 ========================================================================*/

#include "resource.h"

#include <kdemacros.h>
#include <kresources/configwidget.h>

class QLineEdit;
class QComboBox;
class QCheckBox;

namespace KCal {

class CalDavReloadConfig;
class CalDavSaveConfig;

/*=========================================================================
| CLASS
 ========================================================================*/

/**
 * Configuration widget for CalDAV resource.
 */
class KDE_EXPORT ResourceCalDavConfig : public KRES::ConfigWidget
{
    Q_OBJECT

public:

    ResourceCalDavConfig(QWidget *parent = 0);

public Q_SLOTS:

    virtual void loadSettings(KRES::Resource *resource);
    virtual void saveSettings(KRES::Resource *resource);

protected:

    virtual void setupUI();

private:

    QLineEdit *mUrl;
    QComboBox *mEncoding;
    QLineEdit *mUsername;
    QLineEdit *mPassword;
    QCheckBox *mRememberPassword;
    QCheckBox *mUseUTF8;
    CalDavReloadConfig* mReloadConfig;
    CalDavSaveConfig* mSaveConfig;

    static ResourceCalDav* getCalDavResource(KRES::Resource* res);

    /**
     * Returns preferences of the given ResourceCalDav object.
     * @param res resource object.
     * @return if preferences object is obtained successfully, it's returned. Otherwise, NULL is returned.
     */
    static CalDavPrefs* getPrefs(ResourceCalDav* res);
};

} // namespace KCal


#endif //  KCAL_RESOURCECALDAVCONFIG_H

