/*=========================================================================
| KCalDAV
|--------------------------------------------------------------------------
| (c) 2009  Kumaran Santhanam
|
| This project is released under the GNU General Public License.
| Please see the file COPYING for more details.
|--------------------------------------------------------------------------
| Job class for accessing remote calendars.
 ========================================================================*/

/*=========================================================================
| INCLUDES
 ========================================================================*/

#include "job.h"
#include <kdebug.h>
#include <klocalizedstring.h>

#include <QtCore/QMutexLocker>

#define log(s)      kDebug() << s;

/*=========================================================================
| NAMESPACE
 ========================================================================*/

using namespace KCal;

/*=========================================================================
| STATIC
 ========================================================================*/

/*=========================================================================
| CONSTRUCTOR AND DESTRUCTOR
 ========================================================================*/

CalDavJob::CalDavJob(const QString& url) {
    cleanJob();
    setUrl(url);
}

CalDavJob::~CalDavJob() {
}


/*=========================================================================
| METHODS
 ========================================================================*/

void CalDavJob::enableCaldavDebug(runtime_info* rt) {    
    if (rt && rt->options) {
        rt->options->debug = 0; // if debug = 1, it causes major CPU overhead
        rt->options->verify_ssl_certificate = FALSE;
    }
}

void CalDavJob::setErrorString(const QString& err) {
    mError = true;
    mErrorString = err;
}

void CalDavJob::processError(const caldav_error* err) {
    QString error_string;

    long code = err->code;

    if (-401 == code) { // unauthorized
        error_string = i18n("Unauthorized. Username or password incorrect.");
    } else if (-599 <= code && code <= -300) {
        error_string = i18n("HTTP error %1. Maybe, URL is not a CalDAV resource.").arg(-code);
    } else {
        error_string = i18n("Unknown error, code: %1, message: %2").arg(code).arg(err->str);
    }

    setErrorString(error_string);
}


void CalDavJob::run() {
    log("cleaning job");
    cleanJob();

    int res = OK;
    
    runtime_info* caldav_runtime = caldav_get_runtime_info();

#ifdef KCALDAV_DEBUG
    log("setting debug caldav options");
    enableCaldavDebug(caldav_runtime);
#endif // KCALDAV_DEBUG

    log("running job");
    res = runJob(caldav_runtime);

    if (OK != res) {
        log("job failed");
        processError(caldav_runtime->error);
    }    
    
    caldav_free_runtime_info(&caldav_runtime);
}

// EOF ========================================================================
